# sudoku-sat

Solve and generate basic Sudokus and Sudokus with an extended set of rules.

See `sudoku-sat --help` for all options.

Required Python version: `>= 3.9`

## Recommended Installation Instructions

- install `limboole`, either through your system's package manager or manually
- install `sudoku-sat`:
	- `python -m venv .sudoku-sat`
	- `. ./sudoku-sat/bin/activate`
	- `pip install sudoku-sat`

## Manual Installation Instructions

- install `limboole`, either through your system's package manager or manually
	- install `sudoku-sat`:
	- `git clone git@github.com:charludo/sudoku-sat.git`
	- `python -m venv .sudoku-sat`
	- `. .sudoku-sat/bin/activate`
	- `cd sudoku-sat`
	- `pip install -e .`
